import { Component, Prop, Vue } from 'vue-facing-decorator';
import * as L from 'leaflet';
import 'leaflet/dist/leaflet.css';

@Component({
  name: 'Minimap',
})
export default class Minimap extends Vue {
  @Prop({ type: Array, required: true }) bounds!: L.LatLngBoundsLiteral;

  // private originalCenter: L.LatLngExpression = [47.71, 13.55]; // Original center
  // private originalZoom: number = 6; // Original zoom level

  mounted() {
    const map = L.map('map', {
      center: [47.71, 13.55],
      zoomControl: true,
      zoom: 6,
      minZoom: 5,
      maxBounds: [
        [44.0, 9.0], // Southwest corner of the bounds
        [51.0, 18.0]  // Northeast corner of the bounds
      ],
      maxBoundsViscosity: 1
    });
  
    const basemapAtLayer = L.tileLayer('https://maps{s}.wien.gv.at/basemap/geolandbasemap/normal/google3857/{z}/{y}/{x}.png', {
      attribution: '<a href="https://www.basemap.at">basemap.at</a>',
      noWrap: true,
      subdomains: ['', '1', '2', '3', '4']
    }).addTo(map);
  
    const esriImageryLayer = L.tileLayer('https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{z}/{y}/{x}', {
      attribution: 'Tiles &copy; Esri'
    });
  
    const esriTopoLayer = L.tileLayer('https://server.arcgisonline.com/arcgis/rest/services/World_Topo_Map/MapServer/tile/{z}/{y}/{x}', {
      attribution: 'Tiles &copy; Esri'
    });
  
    const baseMaps = {
      "basemap.at": basemapAtLayer,
      "ESRI Imagery": esriImageryLayer,
      "ESRI Topo": esriTopoLayer
    };
  
    L.control.layers(baseMaps).addTo(map);
  
    const [southWest, northEast] = this.bounds;
  
    if (southWest[0] === northEast[0] || southWest[1] === northEast[1]) {
      const center = [southWest[0], southWest[1]] as [number, number];
      const circleMarker = L.circleMarker(center, {
        color: '#30D5C8',
        fillColor: '#336699',
        fillOpacity: 1,
        opacity: 0.5,
        weight: 10,
        radius: 10
      }).addTo(map);
  
      const buffer = 0.01;
      const markerBounds = L.latLngBounds(
        [center[0] - buffer, center[1] - buffer],
        [center[0] + buffer, center[1] + buffer]
      );
  
      circleMarker.on('click', () => {
        map.fitBounds(markerBounds, { padding: [10, 10] });
      });
  
      map.fitBounds(markerBounds, { padding: [10, 10] });
  
    } else {
      const rectangle = L.rectangle(this.bounds, {
        color: '#30D5C8',
        weight: 2,
        opacity: 1
      }).addTo(map);
  
      rectangle.on('click', () => {
        map.fitBounds(this.bounds, { padding: [18, 18] });
      });
  
      // Fit the map's view to the rectangle's bounds with padding
      map.fitBounds(this.bounds, { padding: [18, 18] });
    }
  }
  
}